@@ -464,12 +464,12 @@ class FullModel(pl.LightningModule, NowcastingModelHubMixin):
         """
 
         if use_hf:
-            _LOG.debug('Loading mode from Hugging Face "openclimatefix/power_perceiver" ')
+            _log.debug('Loading mode from Hugging Face "openclimatefix/power_perceiver" ')
             model = FullModel.from_pretrained("openclimatefix/power_perceiver")
-            _LOG.debug("Loading mode from Hugging Face: done")
+            _log.debug("Loading mode from Hugging Face: done")
             return model
         else:
-            _LOG.debug(f"Loading model weights from {local_filename}")
+            _log.debug(f"Loading model weights from {local_filename}")
             model = self.load_from_checkpoint(checkpoint_path=local_filename)
-            _LOG.debug("Loading model weights: done")
+            _log.debug("Loading model weights: done")
             return model
\ No newline at end of file
